/**
 * A drawing canvas that the user can use to draw secret messages.
 * 
 * @author Keith Schwarz (htiek@cs.stanford.edu)
 */

import java.awt.*;
import java.awt.event.*;
import acm.graphics.*;

public class SteganographyDrawingCanvas extends GCanvas implements MouseListener, MouseMotionListener, SteganographyConstants {
	/* Last hit location. */
	private double lastX, lastY;	
		
	/**
	 * Creates a new drawing canvas and installs listeners.
	 */
	public SteganographyDrawingCanvas() {	
		setPreferredSize(new Dimension(CANVAS_WIDTH, CANVAS_HEIGHT));
		
		addMouseListener(this);
		addMouseMotionListener(this);
		setCursor(Cursor.getPredefinedCursor(Cursor.CROSSHAIR_CURSOR));
	}
	
	/**
	 * Clears the display.
	 */
	public void clear() {
		removeAll();
	}

	/**
	 * Mouse listeners.  When the mouse is pressed or dragged, a line is drawn from the last mouse
	 * position to the current mouse position.
	 */
	public void mouseDragged(MouseEvent e) {
		add(new GLine(lastX, lastY, e.getX(), e.getY()));
		lastX = e.getX();
		lastY = e.getY();
	}
	
	public void mousePressed(MouseEvent e) {
		lastX = e.getX();
		lastY = e.getY();
		add(new GLine(lastX, lastY, lastX, lastY));
	}
	
	/**
	 * Clears the canvas, then sets the canvas to contain the indicated image.
	 * 
	 * @param image The image to set as the canvas.
	 */
	public void setImage(GImage image) {
		clear();
		add(new GImage(image.getPixelArray()));
	}
	
	/* Required but unused methods */
	public void mouseClicked(MouseEvent arg0) {}
	public void mouseEntered(MouseEvent arg0) {}
	public void mouseExited(MouseEvent arg0) {}
	public void mouseReleased(MouseEvent arg0) {}
	public void mouseMoved(MouseEvent arg0) {}
}
